# arpes.plotting.fermi\_edge module

**arpes.plotting.fermi\_edge.fermi\_edge\_reference(data, title=None,
ax=None, out=None, norm=None,**kwargs)\*\*

**arpes.plotting.fermi\_edge.plot\_fit(data, title=None, axes=None,
out=None, norm=None,**kwargs)\*\*

> Plots the results of a fit of some lmfit model to some data.
> 
> We introspect the model to determine which attributes we should plot,
> as well as their uncertainties :param data: The data, this should be
> of type DataArray\<lmfit.model.ModelResult\> :param title: :param ax:
> :param out: :param norm: :param kwargs: :return:
